.. grid-strategy code documentation

Code Documentation
==================

.. automodule:: grid_strategy

.. automodule:: grid_strategy.strategies

This is the code documentation for the implementation of 'SquareStrategy' and 'RectangularStrategy'.

SquareStrategy
~~~~~~~~~~~~~~~~~

.. autoclass:: grid_strategy.strategies.SquareStrategy
    :members:

RectanglularStrategy
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: grid_strategy.strategies.RectangularStrategy
    :members:
